cli

package
v1.1.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 14, 2026 License: MIT Imports: 7 Imported by: 0

Documentation

Index

Constants

const Usage = "usage: queryc <schema> <queries> <output> [--dialect postgres|sqlite] [--package name]"

Variables

This section is empty.

Functions

func IsHelp

func IsHelp(err error) bool

IsHelp returns whether parsing stopped for a help request.

func Parse

func Parse(args []string) (app.Options, error)

Parse validates and returns command arguments as structured data.

Types

This section is empty.

Jump to